@@ -129,6 +129,7 @@ void Titraqform::setupPrefs(void)
         m_pPrefs->setString(TITRAQ_PREFASFILE, TITRAQ_DEFASFILE);
         m_pPrefs->setNumber(TITRAQ_PREFSTYLE, TITRAQ_STYLECDE);
         m_pPrefs->setString(TITRAQ_PREFVIEW, TITRAQ_DEFVIEW);
+        m_pPrefs->setNumber(TITRAQ_PREFSORT, TITRAQ_DEFSORT);
         m_pPrefs->setString(TITRAQ_PREFREMOTELOG, TITRAQ_DEFREMOTELOG);
         m_pPrefs->setString(TITRAQ_PREFLOCALLOG, TITRAQ_DEFLOCALLOG);
         m_pPrefs->flush();  // Write the new conf file
@@ -377,6 +378,8 @@ void Titraqform::setupMenubar(void)
     m_pTbarspopup->setItemChecked(nMenuid, true);
     nMenuid = m_pTbarspopup->insertItem(trUtf8("&Edit"), this, SLOT(showEditbar()));
     m_pTbarspopup->setItemChecked(nMenuid, true);
+    nMenuid = m_pTbarspopup->insertItem(trUtf8("&View"), this, SLOT(showViewbar()));
+    m_pTbarspopup->setItemChecked(nMenuid, true);
     nMenuid = m_pTbarspopup->insertItem(trUtf8("&Whats"), this, SLOT(showWhatsbar()));
     m_pTbarspopup->setItemChecked(nMenuid, true);
     m_pViewpopup->insertSeparator();
