@@ -112,6 +112,7 @@
 #define TITRAQ_PREFREMCOLWIDTH    "remarkcolwidth"
 #define TITRAQ_DEFREMCOLWIDTH     120
 
+// Column appearance preferences
 #define TITRAQ_PREFFILEBAR      "filetoolbar"
 #define TITRAQ_DEFFILEBAR       true
 #define TITRAQ_PREFEDITBAR      "edittoolbar"
@@ -121,10 +122,15 @@
 #define TITRAQ_PREFWHATBAR      "whattoolbar"
 #define TITRAQ_DEFWHATBAR       true
 
+// Other value preferences
+#define TITRAQ_PREFSORT         "sortorder"
+#define TITRAQ_DEFSORT          TITRAQ_IDXDATE
+
 // Other string constants
 #define TITRAQ_DATEZERO         "0000-00-00"
 #define TITRAQ_SEPARATORTOK     " "
 #define TITRAQ_SAVEFIRST        "The timesheet contains unsaved changes\nDo you want to save the changes or discard them?"
+#define TITRAQ_OVERWRITE        "A file already exists with the chosen name\nDo you want to overwrite it with new data?"
 
 // Indexes of table columns
 #define TITRAQ_IDXALLCTRLS     -1
