@@ -249,9 +249,6 @@ void Titraqform::loadData(QTextStream &Tstream)
         else
             m_pMaintable->setPixmap(nIter, TITRAQ_IDXSTATUS, Staterror);
 
-        // Insert a line number dynamically
-        m_pMaintable->setText(nIter, TITRAQ_IDXLINE, (QString::number(nIter)).rightJustify(4, QChar('0')));
-
         nIter++;            // The big increment
         Line = trUtf8("");  // Clear line for next round
 
@@ -263,12 +260,19 @@ void Titraqform::loadData(QTextStream &Tstream)
         }
     }
 
+    // Start sorting order correctly according to user preferences
+    m_pMaintable->sortColumn((int)m_pPrefs->getNumber(TITRAQ_PREFSORT, TITRAQ_DEFSORT));
+
+    // Write nonsaving line numbers for all rows
+    for (int nIter = m_pMaintable->numRows() - 1; nIter >= 0; nIter--)
+        m_pMaintable->setText(nIter, TITRAQ_IDXLINE, QString::number(nIter).rightJustify(4, QChar('0')));
+
     m_pMaintable->setUpdatesEnabled(true);      // Update and repaint
     m_pMaintable->setNumRows(nIter);            // No excess rows
     m_pMaintable->setCurrentCell(nIter - 1, 0); // Move focus to last row
 
     if (!bValid)
-        throw Genexcept("Warning, invalid accounting data.");
+        throw Genexcept("Warning: invalid accounting data.");
 }
 
 //
