@@ -455,11 +455,26 @@ void Titraqform::saveFile(void)
 //
 void Titraqform::saveAs(void)
 {
+    int nResult = 0; // For checking user's answer
+
     // First get the selected file name to save to
     QString Filestring = QFileDialog::getSaveFileName(QString::null, QString::null, this);
     if (!Filestring.isEmpty()) {
         *m_szFilename = Filestring;
-        saveFile(); // Finish off by calling the save action
+        if (QFile::exists(*m_szFilename)) {
+            nResult = QMessageBox::warning(this, trUtf8(TITRAQ_APPTITLE),
+                      trUtf8(TITRAQ_OVERWRITE), trUtf8("&Yes"), trUtf8("&No"), NULL, 1, 1);
+            switch (nResult) {
+            case 0: // Overwrite contents
+                this->saveFile();
+                break;
+            case 1: // Don't overwrite
+            default:
+                break;
+            }
+        }
+        else
+            saveFile(); // Finish off by calling the save action
     }
     else {
         // User did not select a valid file and push okay button
@@ -1256,6 +1271,9 @@ void Titraqform::savePrefs(void)
     if (m_pMaintable->columnWidth(TITRAQ_IDXREMARK) > 0)
         m_pPrefs->setNumber(TITRAQ_PREFREMCOLWIDTH, (long)m_pMaintable->columnWidth(TITRAQ_IDXREMARK));
 
+    // Get sorting order from matrix table and pass it to prefs handler
+    m_pPrefs->setNumber(TITRAQ_PREFSORT, (long)m_pMaintable->getSortcol());
+
     // Set frame geometry preferences
     m_pPrefs->setNumber(TITRAQ_PREFFRAMEWIDTH, (long)this->width());
     m_pPrefs->setNumber(TITRAQ_PREFFRAMEHEIGHT, (long)this->height());
