@@ -38,10 +38,15 @@
 class TiTable : public QTable
 {
     Q_OBJECT
+
+private:
+    int m_nSortcol;
+
 public:
     // Try to match QTable's default constructor with an initializer list
     TiTable(QWidget *pParent = 0, const char *szName = 0) : QTable(pParent, szName)
     {
+        m_nSortcol = 0;
         horizontalHeader()->installEventFilter(this);
         this->setEdition(); // Reset edition state
     };
@@ -54,10 +59,12 @@ public:
     // Accessor methods
     const int getEdition(void) {return m_nEdit;};   // Which edited column was confirmed
     void setEdition(const int nEdit = -1) {m_nEdit = nEdit;};   // Set edition status
+    const int getSortcol(void) {return m_nSortcol;};
+    void setSortcol(const int nColin) {m_nSortcol = nColin;};
 
     // Overridden accessors
     void setText(int, int, const QString &);
-    void sortColumn(int nCol, bool bAscend, bool bWhole = true) {QTable::sortColumn(nCol, bAscend, true);};
+    void sortColumn(int nCol, bool bAscend = true, bool bWhole = true);
 //    virtual QTableItem *item(int nRow, int nCol) const {QTable::item(nRow, nCol);};
 
     // Deny a cell special handling of the focus rectangle
